#!/usr/bin/env python

from distutils.core import setup

setup(name='pavlovadm',
      version='0.2',
      description='utility to manage pavlov\'s rcon like admin interface',
      author='d0n',
      author_email='d0n@janeiskla.de',
      url='https://pypi.org/project/pavlovadm/',
      packages=['.'],
     )
